@@ -21,7 +21,7 @@ class ActionAdmin(admin.ModelAdmin):
     The Action model has a CharField PK.
     """
 
-    list_display = ('name', 'description')
+    list_display = ("name", "description")
 
     def remove_url(self, name):
         """
@@ -38,14 +38,15 @@ class ActionAdmin(admin.ModelAdmin):
         def wrap(view):
             def wrapper(*args, **kwargs):
                 return self.admin_site.admin_view(view)(*args, **kwargs)
+
             return update_wrapper(wrapper, view)
 
         info = self.model._meta.app_label, self.model._meta.model_name
 
-        view_name = '%s_%s_add' % info
+        view_name = "%s_%s_add" % info
 
         return [
-            re_path('^!add/$', wrap(self.add_view), name=view_name),
+            re_path("^!add/$", wrap(self.add_view), name=view_name),
         ] + self.remove_url(view_name)
 
 
@@ -54,14 +55,15 @@ class Person(models.Model):
 
 
 class PersonAdmin(admin.ModelAdmin):
-
     def response_post_save_add(self, request, obj):
         return HttpResponseRedirect(
-            reverse('admin:admin_custom_urls_person_history', args=[obj.pk]))
+            reverse("admin:admin_custom_urls_person_history", args=[obj.pk])
+        )
 
     def response_post_save_change(self, request, obj):
         return HttpResponseRedirect(
-            reverse('admin:admin_custom_urls_person_delete', args=[obj.pk]))
+            reverse("admin:admin_custom_urls_person_delete", args=[obj.pk])
+        )
 
 
 class Car(models.Model):
@@ -69,15 +71,17 @@ class Car(models.Model):
 
 
 class CarAdmin(admin.ModelAdmin):
-
     def response_add(self, request, obj, post_url_continue=None):
         return super().response_add(
-            request, obj,
-            post_url_continue=reverse('admin:admin_custom_urls_car_history', args=[obj.pk]),
+            request,
+            obj,
+            post_url_continue=reverse(
+                "admin:admin_custom_urls_car_history", args=[obj.pk]
+            ),
         )
 
 
-site = admin.AdminSite(name='admin_custom_urls')
+site = admin.AdminSite(name="admin_custom_urls")
 site.register(Action, ActionAdmin)
 site.register(Person, PersonAdmin)
 site.register(Car, CarAdmin)
