@@ -1,4 +1,4 @@
-from ..models import models
+from django.contrib.gis.db import models
 
 
 class AllOGRFields(models.Model):
@@ -13,18 +13,12 @@ class AllOGRFields(models.Model):
     geom = models.PolygonField()
     point = models.PointField()
 
-    objects = models.GeoManager()
-
-    class Meta:
-        required_db_features = ['gis_enabled']
-
 
 class Fields3D(models.Model):
     point = models.PointField(dim=3)
+    pointg = models.PointField(dim=3, geography=True)
     line = models.LineStringField(dim=3)
     poly = models.PolygonField(dim=3)
 
-    objects = models.GeoManager()
-
     class Meta:
-        required_db_features = ['gis_enabled']
+        required_db_features = {"supports_3d_storage"}
