@@ -5,9 +5,6 @@ class City(models.Model):
     id = models.BigAutoField(primary_key=True)
     name = models.CharField(max_length=50)
 
-    def __str__(self):
-        return self.name
-
 
 class Country(models.Model):
     id = models.SmallAutoField(primary_key=True)
@@ -18,9 +15,6 @@ class District(models.Model):
     city = models.ForeignKey(City, models.CASCADE, primary_key=True)
     name = models.CharField(max_length=50)
 
-    def __str__(self):
-        return self.name
-
 
 class Reporter(models.Model):
     first_name = models.CharField(max_length=30)
@@ -32,30 +26,26 @@ class Reporter(models.Model):
     interval = models.DurationField()
 
     class Meta:
-        unique_together = ('first_name', 'last_name')
-
-    def __str__(self):
-        return "%s %s" % (self.first_name, self.last_name)
+        unique_together = ("first_name", "last_name")
 
 
 class Article(models.Model):
     headline = models.CharField(max_length=100)
     pub_date = models.DateField()
-    body = models.TextField(default='')
+    body = models.TextField(default="")
     reporter = models.ForeignKey(Reporter, models.CASCADE)
-    response_to = models.ForeignKey('self', models.SET_NULL, null=True)
-    unmanaged_reporters = models.ManyToManyField(Reporter, through='ArticleReporter', related_name='+')
+    response_to = models.ForeignKey("self", models.SET_NULL, null=True)
+    unmanaged_reporters = models.ManyToManyField(
+        Reporter, through="ArticleReporter", related_name="+"
+    )
 
     class Meta:
-        ordering = ('headline',)
+        ordering = ("headline",)
         index_together = [
             ["headline", "pub_date"],
-            ['headline', 'response_to', 'pub_date', 'reporter'],
+            ["headline", "response_to", "pub_date", "reporter"],
         ]
 
-    def __str__(self):
-        return self.headline
-
 
 class ArticleReporter(models.Model):
     article = models.ForeignKey(Article, models.CASCADE)
@@ -74,10 +64,13 @@ class Comment(models.Model):
 
     class Meta:
         constraints = [
-            models.UniqueConstraint(fields=['article', 'email', 'pub_date'], name='article_email_pub_date_uniq'),
+            models.UniqueConstraint(
+                fields=["article", "email", "pub_date"],
+                name="article_email_pub_date_uniq",
+            ),
         ]
         indexes = [
-            models.Index(fields=['email', 'pub_date'], name='email_pub_date_idx'),
+            models.Index(fields=["email", "pub_date"], name="email_pub_date_idx"),
         ]
 
 
@@ -87,8 +80,25 @@ class CheckConstraintModel(models.Model):
 
     class Meta:
         required_db_features = {
-            'supports_table_check_constraints',
+            "supports_table_check_constraints",
         }
         constraints = [
-            models.CheckConstraint(name='up_votes_gte_0_check', check=models.Q(up_votes__gte=0)),
+            models.CheckConstraint(
+                name="up_votes_gte_0_check", check=models.Q(up_votes__gte=0)
+            ),
+        ]
+
+
+class UniqueConstraintConditionModel(models.Model):
+    name = models.CharField(max_length=255)
+    color = models.CharField(max_length=32, null=True)
+
+    class Meta:
+        required_db_features = {"supports_partial_indexes"}
+        constraints = [
+            models.UniqueConstraint(
+                fields=["name"],
+                name="cond_name_without_color_uniq",
+                condition=models.Q(color__isnull=True),
+            ),
         ]
