@@ -14,44 +14,43 @@ undefined -- not random, just undefined.
 """
 
 from django.db import models
-from django.db.models.expressions import OrderBy
 
 
 class Author(models.Model):
     name = models.CharField(max_length=63, null=True, blank=True)
+    editor = models.ForeignKey("self", models.CASCADE, null=True)
 
     class Meta:
-        ordering = ('-pk',)
+        ordering = ("-pk",)
 
 
 class Article(models.Model):
     author = models.ForeignKey(Author, models.SET_NULL, null=True)
-    second_author = models.ForeignKey(Author, models.SET_NULL, null=True, related_name='+')
+    second_author = models.ForeignKey(
+        Author, models.SET_NULL, null=True, related_name="+"
+    )
     headline = models.CharField(max_length=100)
     pub_date = models.DateTimeField()
 
     class Meta:
         ordering = (
-            '-pub_date',
-            models.F('headline'),
-            models.F('author__name').asc(),
-            OrderBy(models.F('second_author__name')),
+            "-pub_date",
+            models.F("headline"),
+            models.F("author__name").asc(),
+            models.OrderBy(models.F("second_author__name")),
         )
 
-    def __str__(self):
-        return self.headline
-
 
 class OrderedByAuthorArticle(Article):
     class Meta:
         proxy = True
-        ordering = ('author', 'second_author')
+        ordering = ("author", "second_author")
 
 
 class OrderedByFArticle(Article):
     class Meta:
         proxy = True
-        ordering = (models.F('author').asc(nulls_first=True), 'id')
+        ordering = (models.F("author").asc(nulls_first=True), "id")
 
 
 class ChildArticle(Article):
@@ -62,4 +61,4 @@ class Reference(models.Model):
     article = models.ForeignKey(OrderedByAuthorArticle, models.CASCADE)
 
     class Meta:
-        ordering = ('article',)
+        ordering = ("article",)
